about summary refs log tree commit diff
path: root/sysdeps/s390/s390-64/elf/start.S
diff options
context:
space:
mode:
Diffstat (limited to 'sysdeps/s390/s390-64/elf/start.S')
-rw-r--r--sysdeps/s390/s390-64/elf/start.S6
1 files changed, 3 insertions, 3 deletions
diff --git a/sysdeps/s390/s390-64/elf/start.S b/sysdeps/s390/s390-64/elf/start.S
index bbc28089f9..687a23cc67 100644
--- a/sysdeps/s390/s390-64/elf/start.S
+++ b/sysdeps/s390/s390-64/elf/start.S
@@ -1,5 +1,5 @@
 /* Startup code compliant to the 64 bit S/390 ELF ABI.
-   Copyright (C) 2001 Free Software Foundation, Inc.
+   Copyright (C) 2001, 2002 Free Software Foundation, Inc.
    Contributed by Martin Schwidefsky (schwidefsky@de.ibm.com).
    This file is part of the GNU C Library.
 
@@ -59,8 +59,8 @@ _start:
 	 */
 	stmg	%r14,%r15,160(%r15)	# store rtld_fini/stack_end to parameter area
 	la	%r7,160(%r15)
-	larl	%r6,_fini		# load pointer to _fini
-	larl	%r5,_init		# load pointer to _init
+	larl	%r6,__libc_csu_fini	# load pointer to __libc_csu_fini
+	larl	%r5,__libc_csu_init	# load pointer to __libc_csu_init
 	larl	%r2,main		# load pointer to main
 
 	/* Ok, now branch to the libc main routine.  */